@@ -2,8 +2,6 @@ from contextvars import ContextVar, Token
 from contextlib import contextmanager
 from typing import Any, Dict, Iterator, Optional
 
-__version__ = "0.3.5"
-__author__ = "Tomasz Wojcik"
 
 _request_scope_context_storage: ContextVar[Dict[Any, Any]] = ContextVar(
     "starlette_context"
@@ -14,11 +12,11 @@ _request_scope_context_storage: ContextVar[Dict[Any, Any]] = ContextVar(
 def request_cycle_context(
     initial_data: Optional[dict] = None,
 ) -> Iterator[None]:
-    """
-    Creates and resets a starlette-context context.
+    """Creates and resets a starlette-context context.
 
-    Used in the Context and Raw middlewares, but can also be used to create a
-    context out of a proper request cycle, such as in unit tests.
+    Used in the Context and Raw middlewares, but can also be used to
+    create a context out of a proper request cycle, such as in unit
+    tests.
     """
     if initial_data is None:
         initial_data = {}
