@@ -24,12 +24,10 @@ CONTEXT_MIDDLEWARE_WARNING_MSG = (
 
 
 class ContextMiddleware(BaseHTTPMiddleware):
-    """
-    Middleware that creates empty context for request it's used on. If not
+    """Middleware that creates empty context for request it's used on. If not
     used, you won't be able to use context object.
 
-    Not to be used with StreamingResponse / FileResponse.
-    https://github.com/encode/starlette/issues/1012#issuecomment-673461832
+    Not to be used with StreamingResponse or FileResponse.
     """
 
     def __init__(
@@ -55,11 +53,10 @@ class ContextMiddleware(BaseHTTPMiddleware):
         self.error_response = default_error_response
 
     async def set_context(self, request: Request) -> dict:
-        """
-        You might want to override this method.
+        """You might want to override this method.
 
-        The dict it returns will be saved in the scope of a context. You can
-        always do that later.
+        The dict it returns will be saved in the scope of a context. You
+        can always do that later.
         """
         return {
             plugin.key: await plugin.process_request(request)
